pub struct StarnixVolumeProviderCheckRequest {
pub crypt: ClientEnd<CryptMarker>,
}Fields
crypt: ClientEnd<CryptMarker>Trait Implementations
Sourceimpl Decode<StarnixVolumeProviderCheckRequest, DefaultFuchsiaResourceDialect> for StarnixVolumeProviderCheckRequest
impl Decode<StarnixVolumeProviderCheckRequest, DefaultFuchsiaResourceDialect> for StarnixVolumeProviderCheckRequest
Sourceimpl Encode<StarnixVolumeProviderCheckRequest, DefaultFuchsiaResourceDialect> for &mut StarnixVolumeProviderCheckRequest
impl Encode<StarnixVolumeProviderCheckRequest, DefaultFuchsiaResourceDialect> for &mut StarnixVolumeProviderCheckRequest
Sourceimpl<T0: Encode<Endpoint<ClientEnd<CryptMarker>>, DefaultFuchsiaResourceDialect>> Encode<StarnixVolumeProviderCheckRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Endpoint<ClientEnd<CryptMarker>>, DefaultFuchsiaResourceDialect>> Encode<StarnixVolumeProviderCheckRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Ord for StarnixVolumeProviderCheckRequest
impl Ord for StarnixVolumeProviderCheckRequest
Sourcefn cmp(&self, other: &StarnixVolumeProviderCheckRequest) -> Ordering
fn cmp(&self, other: &StarnixVolumeProviderCheckRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StarnixVolumeProviderCheckRequest
impl PartialEq for StarnixVolumeProviderCheckRequest
Sourcefn eq(&self, other: &StarnixVolumeProviderCheckRequest) -> bool
fn eq(&self, other: &StarnixVolumeProviderCheckRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for StarnixVolumeProviderCheckRequest
impl PartialOrd for StarnixVolumeProviderCheckRequest
Sourceimpl ResourceTypeMarker for StarnixVolumeProviderCheckRequest
impl ResourceTypeMarker for StarnixVolumeProviderCheckRequest
Sourcetype Borrowed<'a> = &'a mut StarnixVolumeProviderCheckRequest
type Borrowed<'a> = &'a mut StarnixVolumeProviderCheckRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for StarnixVolumeProviderCheckRequest
impl TypeMarker for StarnixVolumeProviderCheckRequest
Sourcetype Owned = StarnixVolumeProviderCheckRequest
type Owned = StarnixVolumeProviderCheckRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for StarnixVolumeProviderCheckRequest
impl Standalone<DefaultFuchsiaResourceDialect> for StarnixVolumeProviderCheckRequest
impl StructuralPartialEq for StarnixVolumeProviderCheckRequest