StarnixVolumeProviderProxy

Struct StarnixVolumeProviderProxy 

pub struct StarnixVolumeProviderProxy { /* private fields */ }

Implementations

Source

impl StarnixVolumeProviderProxy

pub fn new(channel: AsyncChannel) -> Self

Create a new Proxy for fuchsia.fshost/StarnixVolumeProvider.

pub fn take_event_stream(&self) -> StarnixVolumeProviderEventStream

Get a Stream of events from the remote end of the protocol.

Panics

Panics if the event stream was already taken.

pub fn check( &self, crypt: ClientEnd<CryptMarker>, ) -> QueryResponseFut<StarnixVolumeProviderCheckResult, DefaultFuchsiaResourceDialect>

Checks the integrity of the main starnix volume if it exists.

Silently succeeds if the volume is absent, or if fshost is not configured to check filesystems (fuchsia.fshost.CheckFilesystems).

pub fn mount( &self, crypt: ClientEnd<CryptMarker>, mode: MountMode, exposed_dir: ServerEnd<DirectoryMarker>, ) -> QueryResponseFut<StarnixVolumeProviderMountResult, DefaultFuchsiaResourceDialect>

Mounts the main starnix volume using crypt. exposed_dir will be connected to the exposed directory of the mounted starnix volume.

If mode is MAYBE_CREATE, the volume will be created if it does not exist. If mode is ALWAYS_CREATE, the volume will be created, overwriting any existing volume.

Returns the GUID of the mounted volume.