StarnixVolumeProviderSynchronousProxy

Struct StarnixVolumeProviderSynchronousProxy 

pub struct StarnixVolumeProviderSynchronousProxy { /* private fields */ }

Implementations

Source

impl StarnixVolumeProviderSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<StarnixVolumeProviderEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn check( &self, crypt: ClientEnd<CryptMarker>, ___deadline: MonotonicInstant, ) -> Result<StarnixVolumeProviderCheckResult, Error>

Checks the integrity of the main starnix volume if it exists.

Silently succeeds if the volume is absent, or if fshost is not configured to check filesystems (fuchsia.fshost.CheckFilesystems).

pub fn mount( &self, crypt: ClientEnd<CryptMarker>, mode: MountMode, exposed_dir: ServerEnd<DirectoryMarker>, ___deadline: MonotonicInstant, ) -> Result<StarnixVolumeProviderMountResult, Error>

Mounts the main starnix volume using crypt. exposed_dir will be connected to the exposed directory of the mounted starnix volume.

If mode is MAYBE_CREATE, the volume will be created if it does not exist. If mode is ALWAYS_CREATE, the volume will be created, overwriting any existing volume.

Returns the GUID of the mounted volume.